#
# spec file for package nasc
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid com.github.parnold-x.nasc
Name:           nasc
Version:        0.5.4
Release:        3.4
Summary:        Do maths like a normal person
License:        GPL-3.0-only
Group:          Productivity/Scientific/Math
URL:            https://github.com/parnoldx/nasc
Source:         %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM nasc-fix_gcc9_build.patch
Patch0:         nasc-fix_gcc9_build.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.28.0
BuildRequires:  pkgconfig(cln)
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(granite)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtksourceview-3.0)
BuildRequires:  pkgconfig(libqalculate)
BuildRequires:  pkgconfig(libsoup-2.4)
Requires:       qalculate
Requires:       %(rpm -qf $(readlink -qne %{_libdir}/libcln.so) --qf '%%{NAME} >= %%{VERSION}')

%description
This is an application where you do calculations "like a normal
person". It lets you type whatever you want, smartly figures out what
computations are needed, and outputs an answer on the right pane.
Then you can plug those answers in to future equations and if that
answer changes, so does the equations it is used in.

%prep
%autosetup -p1

%build
export CFLAGS="%{optflags} -Wno-implicit-function-declaration"
%cmake
%cmake_build

%install
%cmake_install

%files
%license COPYING
%doc AUTHORS README.md
%{_bindir}/%{appid}
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/icons/hicolor/*/apps/%{appid}.svg
%{_datadir}/metainfo/%{appid}.appdata.xml
%{_datadir}/qalculate/

%changelog
* Sun Nov 24 2024 Richard Rahl <rrahl0@opensuse.org>
- fix build by using CFLAGS="-Wno-implicit-function-declaration"
- update spec file for Leap 16.0:
  * remove %%suse_update_desktop_file
  * use autosetup
  * remove packaging for Leap < 1500
  * update to newer upstream url
* Sun Dec  8 2019 Luigi Baldoni <aloisio@gmx.com>
- Added nasc-fix_gcc9_build.patch
* Mon May 13 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 0.5.4:
  * Update com.github.parnold-x.nasc.desktop
  * Update com.github.parnold-x.nasc.appdata.xml
  * Update README.md
* Mon Feb 18 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 0.5.2:
  * CMake: Remove --thread option for Vala Compiler
  * CMake: Fix linking
  * Enhance AppData file
  * Enhance desktop file
  * Use get_user_data_dir() instead of hardcoded path
  * Update control
- Drop nasc-0.5.0-link.patch (fixed)
* Sun Nov 11 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 0.5.1:
  * Update .travis.yml
* Mon Oct 29 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 0.5.0:
  * Update com.github.parnold-x.nasc.appdata.xml
  * Update Appdata Infos
  * revert static lib commit because it does not work and rename
    binary
  * don't build libqalculatenasc shared library, but link directly
- Update nasc-0.4.7-link.patch > nasc-0.5.0-link.patch
- Spec file cleanup
* Tue Apr  3 2018 avvissu@yandex.by
- Update to 0.4.7:
  * Update CMakeLists.txt
  * revert forward2
  * Require C++11 in CMake
  * Fix a couple more deprecation warnings
  * Remove deprecated granite metadata for about dialog
  * Use CMake to build libqalculatenasc
- Add sln as required dependency
- Build app with static library
- Build with -Wl,--no-undefined
- Add nasc-0.4.7-link.patch
* Thu Oct  5 2017 avvissu@yandex.by
- Update to 0.4.6:
  * CMake: Include GNUInstallDirs
  * Use NOT DEFINED to check for CMake variables
  * Allow overriding STYLEDIR and DATADIR on build
  * Update README.md
  * remove template, styleDir as Cmake variable, fix exchange
    rates loading
  * Update rules
  * Create qalculation config dir if it does not exist.
- Drop libdir.patch (fixed in upstream)
* Mon Aug 21 2017 avvissu@yandex.by
- Update to 0.4.5:
  * Update CMakeLists.txt
  * Update PasteBinDialog.vala
- Use appdata instead of metainfo
* Fri Jul 21 2017 avvissu@yandex.by
- Update to 0.4.3:
  * Merge pull request #55 from nick87720z/patch-1
  * ResultView.vala - color value types and alpha
  * add a timeout for the update thread, reverse lib dir makro
  * Update com.github.parnold-x.nasc.desktop
  * Update README.md
  * Merge pull request #48 from parnold-x/master
  * Merge pull request #47 from Mailaender/patch-1
  * Use CMake macros to determine the proper libdir
- Update libdir.patch
* Tue Jun 20 2017 avvissu@yandex.by
- Update the homepage
- Build without compile GSettings schema
- Add qalculate as required dependency
* Sun Jun  4 2017 mailaender@opensuse.org
- Add libdir.patch to fix 64-bit installations
* Mon May 29 2017 avvissu@yandex.by
- Update to 0.4.2:
  * Merge pull request #43 from Streppel/nasc
  * added dependencies to README.md
  * added hint on how to get degrees
* Fri May 26 2017 mailaender@opensuse.org
- Update to version 0.4.1
* Tue May  9 2017 avvissu@yandex.by
- Fix build on openSUSE > 42.2 (add nasc-0.2-include.patch)
- Update nasc-0.2_build.patch
- Spec file cleanup
* Thu Jan 12 2017 avvissu@yandex.by
- Fix build on openSUSE > 42.2 (add nasc-0.2_build.patch)
* Fri Mar  4 2016 and.november@opensuse.org
- initial package (version 0.2) for openSUSE
